#!/usr/bin/zsh
############################################################
### Slurm flags
############################################################

#SBATCH --time=00:15:00
#SBATCH --partition=c23g
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=1
#SBATCH --cpus-per-task=24
#SBATCH --gres=gpu:1

############################################################
### Load modules or software
############################################################

# load module for PyTorch container
module load PyTorch/nvcr-24.01-py3
module list

############################################################
### Parameters and Settings
############################################################

# print some information about current system
echo "Job nodes: ${SLURM_JOB_NODELIST}"
echo "Current machine: $(hostname)"
nvidia-smi

# specify that utilization monitoring via nvidia-smi should be done
export ENABLE_MONITORING=1

############################################################
### Execution (Model Training)
############################################################

if [ "${ENABLE_MONITORING:-0}" = "1" ]; then
    # start monitoring process in the background (every 2 sec)
    nvidia-smi --query-gpu=timestamp,index,compute_mode,pstate,utilization.gpu,utilization.memory,memory.used,temperature.gpu,power.draw \
        --format=csv --loop=2 &> gpu_monitoring_${SLURM_JOBID}.txt &
    # remember ID of process that has just been started in background
    export proc_id_monitor=$!
fi

# run the python script inside the container
apptainer exec -e --nv ${PYTORCH_IMAGE} \
    bash -c "python train_model.py"

if [ "${ENABLE_MONITORING:-0}" = "1" ]; then
    # end monitoring process again
    kill -2 ${proc_id_monitor}
    sleep 5
fi