#!/usr/bin/zsh
############################################################
### Slurm flags
############################################################

#SBATCH --time=00:15:00
#SBATCH --partition=c23g
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=2
#SBATCH --cpus-per-task=24
#SBATCH --gres=gpu:2

############################################################
### Load modules or software
############################################################

# load module for PyTorch container
module load PyTorch/nvcr-24.01-py3
module list

############################################################
### Parameters and Settings
############################################################

# print some information about current system
echo "Job nodes: ${SLURM_JOB_NODELIST}"
echo "Current machine: $(hostname)"
nvidia-smi

# variables required for distributed runs with DDP
export MASTER_ADDR=$(hostname)
export MASTER_PORT=12340 # error --> change to different port
export NCCL_DEBUG=INFO

############################################################
### Execution (Model Training)
############################################################

# each process sets required environment variables and
# runs the python script inside the container
srun zsh -c '\
    source set_vars.sh && \
    apptainer exec -e --nv ${PYTORCH_IMAGE} \
        bash -c "python train_model.py --distributed"'