#!/usr/bin/zsh
############################################################
### Slurm flags
############################################################

#SBATCH --time=00:15:00
#SBATCH --partition=c23g
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=2
#SBATCH --cpus-per-task=24
#SBATCH --gres=gpu:2

############################################################
### Load modules or software
############################################################

# load module for TensorFlow container
module load TensorFlow/nvcr-24.01-tf2-py3
module list

############################################################
### Parameters and Settings
############################################################

# print some information about current system
echo "Job nodes: ${SLURM_JOB_NODELIST}"
echo "Current machine: $(hostname)"
nvidia-smi

export NCCL_DEBUG=INFO
export TF_CPP_MIN_LOG_LEVEL=1 # disable info messages
export TF_GPU_THREAD_MODE='gpu_private'
export NCCL_SOCKET_NTHREADS=8 # multi-threading for NCCL communication

############################################################
### Execution (Model Training)
############################################################

# TensorFlow in container often needs a tmp directory
NEWTMP=$(pwd)/tmp
mkdir -p ${NEWTMP}

# each process sets required environment variables and
# runs the python script inside the container
source set_vars.sh
apptainer exec -e --nv -B ${NEWTMP}:/tmp ${TENSORFLOW_IMAGE} \
    bash -c "python -W ignore train_model.py --strategy 'mirrored'"
